==> qtjambi-scxml-debuginfo-macos-5.15.17.jar: sources/QtJambiScxml/QScxmlCppDataModel_shell.h <==
#ifndef QSCXMLCPPDATAMODEL_SHELL_H
#define QSCXMLCPPDATAMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtScxml/qscxmlcppdatamodel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmldatamodel.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlCppDataModel_shell : public QScxmlCppDataModel, public QtJambiShellInterface
{
public:
    QScxmlCppDataModel_shell(QObject* parent0 = nullptr);
    ~QScxmlCppDataModel_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void evaluateAssignment(qint32 id0, bool* ok1) override;
    void evaluateForeach(qint32 id0, bool* ok1, QScxmlDataModel::ForeachLoopBody* body2) override;
    void evaluateInitialization(qint32 id0, bool* ok1) override;
    bool evaluateToBool(qint32 id0, bool* ok1) override;
    QString evaluateToString(qint32 id0, bool* ok1) override;
    QVariant evaluateToVariant(qint32 id0, bool* ok1) override;
    void evaluateToVoid(qint32 id0, bool* ok1) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasScxmlProperty(const QString& name0) const override;
    QVariant scxmlProperty(const QString& name0) const override;
    bool setScxmlProperty(const QString& name0, const QVariant& value1, const QString& context2) override;
    bool setup(const QMap<QString, QVariant>& initialDataValues0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlCppDataModel_access : public QScxmlCppDataModel
{
    void __qt_evaluateAssignment_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    void __qt_evaluateForeach_qint32_bool_ptr_QScxmlDataModel_ForeachLoopBody_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1, QtJambiNativeID body2);
    void __qt_evaluateInitialization_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jboolean __qt_evaluateToBool_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jstring __qt_evaluateToString_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jobject __qt_evaluateToVariant_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    void __qt_evaluateToVoid_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jboolean __qt_hasScxmlProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_scxmlProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jboolean __qt_setScxmlProperty_cref_QString_cref_QVariant_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1, jstring context2);
    jboolean __qt_setup_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject initialDataValues0);
};

#endif // QSCXMLCPPDATAMODEL_SHELL_H

==> qtjambi-scxml-debuginfo-macos-6.5.3.jar: sources/QtJambiScxml/QScxmlCppDataModel_shell.h <==
#ifndef QSCXMLCPPDATAMODEL_SHELL_H
#define QSCXMLCPPDATAMODEL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtScxml/qscxmlcppdatamodel.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmldatamodel.h>
#include <QtScxml/qscxmlevent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlCppDataModel_shell : public QScxmlCppDataModel, public QtJambiShellInterface
{
public:
    QScxmlCppDataModel_shell(QObject* parent0 = nullptr);
    ~QScxmlCppDataModel_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void evaluateAssignment(qint32 id0, bool* ok1) override;
    void evaluateForeach(qint32 id0, bool* ok1, QScxmlDataModel::ForeachLoopBody* body2) override;
    void evaluateInitialization(qint32 id0, bool* ok1) override;
    bool evaluateToBool(qint32 id0, bool* ok1) override;
    QString evaluateToString(qint32 id0, bool* ok1) override;
    QVariant evaluateToVariant(qint32 id0, bool* ok1) override;
    void evaluateToVoid(qint32 id0, bool* ok1) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool hasScxmlProperty(const QString& name0) const override;
    QVariant scxmlProperty(const QString& name0) const override;
    bool setScxmlProperty(const QString& name0, const QVariant& value1, const QString& context2) override;
    bool setup(const QMap<QString, QVariant>& initialDataValues0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlCppDataModel_access : public QScxmlCppDataModel
{
    void __qt_evaluateAssignment_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    void __qt_evaluateForeach_qint32_bool_ptr_QScxmlDataModel_ForeachLoopBody_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1, QtJambiNativeID body2);
    void __qt_evaluateInitialization_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jboolean __qt_evaluateToBool_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jstring __qt_evaluateToString_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jobject __qt_evaluateToVariant_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    void __qt_evaluateToVoid_qint32_bool_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0, jbooleanArray ok1);
    jboolean __qt_hasScxmlProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_scxmlProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jboolean __qt_setScxmlProperty_cref_QString_cref_QVariant_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1, jstring context2);
    jboolean __qt_setup_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jobject initialDataValues0);
};

#endif // QSCXMLCPPDATAMODEL_SHELL_H
